### Pyzub: Manipulate subtitles

Pyzub is a simple utility for manipulating subtitles.

### Installation

Run `pip install pyzub`.

### Usage

```
$ autosub -h
Usage: pyzub slide [OPTIONS] FILEPATH

Options:
  --hours INTEGER
  --minutes INTEGER
  --seconds INTEGER
  --milliseconds INTEGER
  --overwrite             Modifies the subtitle file in place.
  --verbose               Displays a progress bar and a message when finished.
  --help, -h              Show this message and exit.
```

### License

_MIT_

